searchData={"items":[{"type":"module","title":"TinyAES","doc":"TinyAES is a lightweight, dependency-free Elixir wrapper for AES-256-GCM encryption and decryption\nusing Erlang's `:crypto` module. It provides robust error handling, support for Additional\nAuthenticated Data (AAD), and a simple API. The encryption key is securely retrieved from\nthe `ENCRYPTION_KEY` environment variable.","ref":"TinyAES.html"},{"type":"module","title":"Features - TinyAES","doc":"- **Lightweight**: Less than 50 lines of core code.\n- **Dependency-Free**: Relies only on Erlang's `:crypto` module.\n- **Robust Error Handling**: Covers returned `:error`, raised `{etag, reason, stack}` exceptions, and key validation errors.\n- **AES-256-GCM**: Secure, authenticated encryption with 16-byte IV and tag.\n- **AAD Support**: Optional Additional Authenticated Data for enhanced security.\n- **Key Management**: Environment-based key retrieval with Base64 encoding.\n- **3-tuples Compatible**: Handles the latest `:crypto` exceptions formats introduced with Erlang OTP 25.","ref":"TinyAES.html#module-features"},{"type":"module","title":"Setup - TinyAES","doc":"Generate a 32-byte encryption key, and add it to your `.env` file:\n```bash\nmix run -e 'TinyAES.puts_generate_key_env()'\n# Copy the output to .env:\nENCRYPTION_KEY=your_base64_encoded_key_here\n```\nAdd the output to your `.env` file as `ENCRYPTION_KEY=your_base64_encoded_key_here`.\nEnsure the `ENCRYPTION_KEY` environment variable is set in your application.","ref":"TinyAES.html#module-setup"},{"type":"module","title":"Usage - TinyAES","doc":"```elixir\nplaintext = \"Hello, world!\"\nciphertext = TinyAES.encrypt(plaintext, \"optional_aad\")\n{:ok, decrypted} = TinyAES.decrypt(ciphertext, \"optional_aad\")\n# decrypted == \"Hello, world!\"\n```","ref":"TinyAES.html#module-usage"},{"type":"module","title":"Security Notes - TinyAES","doc":"Uses :crypto.strong_rand_bytes/1 for cryptographically secure IV and key generation.\nRequires a 32-byte key, base64-encoded in the ENCRYPTION_KEY environment variable.\nAlways use the same AAD for encryption and decryption to ensure successful authentication.","ref":"TinyAES.html#module-security-notes"},{"type":"function","title":"TinyAES.decrypt/2","doc":"Decrypts AES-256-GCM ciphertext with robust error handling.\nExpects a binary ciphertext containing a 16-byte IV, a 16-byte tag, and the encrypted data.\nOptionally accepts Additional Authenticated Data (AAD) matching the encryption AAD.\nUses the key from `get_key_env/0`.\nReturns `{:ok, plaintext}` on success or `{:error, reason}` on failure, handling:\n- Invalid ciphertext format (e.g., too short).\n- Failed tag verification (`:error`).\n- Invalid arguments (e.g., wrong key size, raised as {`badarg, reason, stack`}).\n- Invalid or missing encryption key.\n- Unexpected errors.","ref":"TinyAES.html#decrypt/2"},{"type":"function","title":"Parameters - TinyAES.decrypt/2","doc":"- `ciphertext`: Binary containing `< >`.\n- `aad`: Additional Authenticated Data used during encryption (string or binary, optional, defaults to `\"\"`).","ref":"TinyAES.html#decrypt/2-parameters"},{"type":"function","title":"Examples - TinyAES.decrypt/2","doc":"iex> ciphertext = TinyAES.encrypt(\"Hello, world!\")\n    iex> TinyAES.decrypt(ciphertext)\n    {:ok, \"Hello, World!\"}\n\n    iex> TinyAES.decrypt(encrypted, \"wrong_aad\")\n    {:error, \"Decryption failed: unknown error\"}\n\n    iex> TinyAES.decrypt(<<0::128>>)\n    {:error, \"Ciphertext must be a binary with at least 32 bytes\"}\n\n    iex> TinyAES.decrypt(\"not a binary\")\n    {:error, \"Ciphertext must be a binary with at least 32 bytes\"}\n\n    iex> System.delete_env(\"ENCRYPTION_KEY\")\n    iex> TinyAES.decrypt(TinyAES.encrypt(\"test\"))\n    {:error, \"Encryption key not found in environment variable ENCRYPTION_KEY\"}","ref":"TinyAES.html#decrypt/2-examples"},{"type":"function","title":"TinyAES.encrypt/2","doc":"Encrypts plaintext using AES-256-GCM, returning a binary containing the IV, tag, and ciphertext.\nOptionally accepts Additional Authenticated Data (AAD) for enhanced security. The plaintext is converted\nto a binary with `to_string/1`. Uses a 32-byte key from `get_key_env/0` and a random 16-byte IV.","ref":"TinyAES.html#encrypt/2"},{"type":"function","title":"Parameters - TinyAES.encrypt/2","doc":"- plaintext: The data to encrypt (string or binary).\n- aad: Additional Authenticated Data (string or binary, optional, defaults to `\"\"`).","ref":"TinyAES.html#encrypt/2-parameters"},{"type":"function","title":"Returns - TinyAES.encrypt/2","doc":"- `binary()`: `< >` on success.\n- `{:error, String.t()}`: If the encryption key is invalid.","ref":"TinyAES.html#encrypt/2-returns"},{"type":"function","title":"Examples - TinyAES.encrypt/2","doc":"iex> ciphertext = TinyAES.encrypt(\"Hello, world!\")\n    iex> byte_size(ciphertext) >= 32\n    true\n\n    iex> ciphertext = TinyAES.encrypt(\"data\", \"aad\")\n    iex> {:ok, \"data\"} = TinyAES.decrypt(ciphertext, \"aad\")\n\n    iex> System.delete_env(\"ENCRYPTION_KEY\")\n    iex> TinyAES.encrypt(\"test\")\n    {:error, \"Encryption key not found in environment variable ENCRYPTION_KEY\"}","ref":"TinyAES.html#encrypt/2-examples"},{"type":"function","title":"TinyAES.generate_key_env/0","doc":"Generates a secure 32-byte key and convert it to a Base64-encoded string for use in `.env` files.\nUse this to create a key for the `ENCRYPTION_KEY` environment variable. See `puts_generate_key_env/0`\nto print the key directly.","ref":"TinyAES.html#generate_key_env/0"},{"type":"function","title":"Returns - TinyAES.generate_key_env/0","doc":"- a Base64-encoded string.","ref":"TinyAES.html#generate_key_env/0-returns"},{"type":"function","title":"Examples - TinyAES.generate_key_env/0","doc":"iex> key = TinyAES.generate_key_env()\n    iex> String.length(key) > 0\n    true\n\n    iex> {:ok, decoded} = Base.decode64(TinyAES.generate_key_env())\n    iex> byte_size(decoded)\n    32","ref":"TinyAES.html#generate_key_env/0-examples"},{"type":"function","title":"TinyAES.get_key_env/0","doc":"Retrieves and decodes a 32-byte encryption key from the `ENCRYPTION_KEY` environment variable.\nThe key must be a Base64-encoded 32-byte string.","ref":"TinyAES.html#get_key_env/0"},{"type":"function","title":"Returns - TinyAES.get_key_env/0","doc":"- `{:ok, binary()}`: A 32-byte binary key on success.\n- `{:error, String.t()}`: An error if:\n  - `ENCRYPTION_KEY` is not set.\n  - The key is not a valid 32-byte Base64-encoded string.","ref":"TinyAES.html#get_key_env/0-returns"},{"type":"function","title":"Examples - TinyAES.get_key_env/0","doc":"iex> System.put_env(\"ENCRYPTION_KEY\", TinyAES.generate_key_env())\n    iex> {:ok, key} = TinyAES.get_key_env()\n    iex> byte_size(key)\n    32\n\n    iex> System.delete_env(\"ENCRYPTION_KEY\")\n    iex> TinyAES.get_key_env()\n    {:error, \"Encryption key not found in environment variable ENCRYPTION_KEY\"}\n\n    iex> System.put_env(\"ENCRYPTION_KEY\", \"invalid\")\n    iex> TinyAES.get_key_env()\n    {:error, \"Invalid encryption key: must be a 32-byte base64-encoded string\"}","ref":"TinyAES.html#get_key_env/0-examples"},{"type":"function","title":"TinyAES.puts_generate_key_env/0","doc":"Generates a secure 32-byte key, prints it as a Base64-encoded string for use in `.env` files, and returns `:ok`.\nAdd the output to your `.env` or `.env.dev` file as `ENCRYPTION_KEY=your_base64_encoded_key_here`.","ref":"TinyAES.html#puts_generate_key_env/0"},{"type":"function","title":"Returns - TinyAES.puts_generate_key_env/0","doc":"- `:ok`","ref":"TinyAES.html#puts_generate_key_env/0-returns"},{"type":"function","title":"Examples - TinyAES.puts_generate_key_env/0","doc":"iex> TinyAES.puts_generate_key_env()\n    # Prints: \"PNu96VvFplhWeR/ojYPtDHiTgAdGxjPs9NGKl0Zn3fA=\" (example; actual key is random)\n    :ok","ref":"TinyAES.html#puts_generate_key_env/0-examples"},{"type":"extras","title":"TinyAES","doc":"# TinyAES\n\n[![License](https://img.shields.io/badge/License-MIT-blue.svg)](https://github.com/Eygem/tiny_aes/blob/main/LICENSE)\n[![Build Status](https://github.com/Eygem/tiny_aes/actions/workflows/ci.yml/badge.svg)](https://github.com/Eygem/tiny_aes/actions)\n\n**TinyAES** is a lightweight, dependency-free Elixir wrapper for AES-256-GCM encryption and decryption using Erlang's `:crypto` module. It provides robust error handling, support for Additional Authenticated Data (AAD), and a simple API. The encryption key is securely retrieved from the `ENCRYPTION_KEY` environment variable.","ref":"readme.html"},{"type":"extras","title":"Features - TinyAES","doc":"- **Lightweight**: Less than 50 lines of core code.\n- **Dependency-Free**: Relies only on Erlang's `:crypto` module.\n- **Robust Error Handling**: Covers returned `:error`, raised `{etag, reason, stack}` exceptions, and key validation errors.\n- **AES-256-GCM**: Secure, authenticated encryption with 16-byte IV and tag.\n- **AAD Support**: Optional Additional Authenticated Data for enhanced security.\n- **Key Management**: Environment-based key retrieval with Base64 encoding.\n- **3-tuples Compatible**: Handles the latest `:crypto` exception format introduced with Erlang OTP 25.","ref":"readme.html#features"},{"type":"extras","title":"Installation - TinyAES","doc":"Add **TinyAES** to your `mix.exs` dependencies:\n```elixir\n{:tiny_aes, \"~> 0.1\"}\n```\nRun `mix deps.get` to fetch the dependency.","ref":"readme.html#installation"},{"type":"extras","title":"Setup - TinyAES","doc":"Generate a 32-byte encryption key, and add it to your `.env` file:\n```bash\nmix run -e 'TinyAES.puts_generate_key_env()'\n# Copy the output to .env:\nENCRYPTION_KEY=your_base64_encoded_key_here\n```\nThe function outputs a base64-encoded key, e.g., `OuaO+dtNNgxJjQLGHMLJ9m8rSQDsVdqkGrf7ySSj3Yg=`. Add the key to your `.env` file:\n\nEnsure the `ENCRYPTION_KEY` environment variable is set in your application (e.g., using [`env_loader`](https://github.com/Eygem/env_loader) or [`dotenv`](https://github.com/avdi/dotenv_elixir)).","ref":"readme.html#setup"},{"type":"extras","title":"Usage - TinyAES","doc":"Encrypt and decrypt data without optional AAD::\n```elixir\n# Encrypt a message\nplaintext = \"Sensitive data\"\nciphertext = TinyAES.encrypt(plaintext)\n\n# Decrypt it\n{:ok, decrypted} = TinyAES.decrypt(ciphertext)\nassert decrypted == plaintext\n```\n\nEncrypt and decrypt data with optional AAD (e.g., user or session ID)\n```elixir\n# Encrypt a message\nplaintext = \"Sensitive data\"\nciphertext = TinyAES.encrypt(plaintext, \"optional_aad\")\n\n# Decrypt it\n{:ok, decrypted} = TinyAES.decrypt(ciphertext, \"optional_aad\")\nassert decrypted == plaintext\n```\n\nHandle edge cases:\n```elixir\n# Handle invalid input\nTinyAES.decrypt(\"not a binary\")\n# {:error, \"Ciphertext must be a binary with at least 32 bytes\"}\n\n# Handle missing key\nSystem.delete_env(\"ENCRYPTION_KEY\")\nTinyAES.encrypt(\"test\")\n# {:error, \"Encryption key not found in environment variable ENCRYPTION_KEY\"}\n```","ref":"readme.html#usage"},{"type":"extras","title":"API - TinyAES","doc":"- `TinyAES.encrypt(plaintext, aad \\\\ \"\")`:\n    - Encrypts plaintext, returning `< >` or `{:error, reason}`.\n- `TinyAES.decrypt(ciphertext, aad \\\\ \"\")`:\n    - Decrypts ciphertext, returning `{:ok, plaintext}` or `{:error, reason}`.\n- `TinyAES.puts_generate_key_env()`:\n    - Generates, prints, and returns `:ok` for a Base64-encoded 32-byte key.\n- `TinyAES.generate_key_env()`:\n    - Generates a Base64-encoded 32-byte key.\n- `TinyAES.get_key_env()`:\n    - Retrieves and decodes the key from `ENCRYPTION_KEY` returning `{:ok, key}` or `{:error, reason}`.\n\n\n\nSee [HexDocs](https://hex.pm/packages/tiny_aes) for full documentation.","ref":"readme.html#api"},{"type":"extras","title":"Contributing - TinyAES","doc":"Contributions are welcome! Please open an issue or pull request on [GitHub](https://github.com/Eygem/tiny_aes). For major changes, discuss them in an issue first. Ensure tests pass with `mix test`.","ref":"readme.html#contributing"},{"type":"extras","title":"License - TinyAES","doc":"Released under the MIT License. See the **[LICENSE](https://github.com/Eygem/tiny_aes/blob/main/LICENSE)** file for details.","ref":"readme.html#license"},{"type":"extras","title":"Acknowledgments - TinyAES","doc":"Developed with the help of Grok, created by xAI. Thanks to Erlang's `:crypto` for providing a solid foundation.","ref":"readme.html#acknowledgments"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}